@@ -5,32 +5,54 @@ Zabbix::Check - System and service checks for Zabbix
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
 System and service checks for Zabbix
 
+	UserParameter=cpan.zabbix.check.installed,/usr/bin/env bash -c "/usr/bin/perl -MZabbix::Check 2>/dev/null; if [ \$? -eq 0 ]; then echo 1; else echo 0; fi"
 	UserParameter=cpan.zabbix.check.version,/usr/bin/perl -MZabbix::Check -e_version
-
-=head3 version
-
-gets Zabbix::Check version
-
-=head2 Disk
-
-Zabbix check for disk
-
+	# Disk
 	UserParameter=cpan.zabbix.check.disk.discovery,/usr/bin/perl -MZabbix::Check::Disk -e_discovery
 	UserParameter=cpan.zabbix.check.disk.bps[*],/usr/bin/perl -MZabbix::Check::Disk -e_bps -- $1 $2
 	UserParameter=cpan.zabbix.check.disk.iops[*],/usr/bin/perl -MZabbix::Check::Disk -e_iops -- $1 $2
 	UserParameter=cpan.zabbix.check.disk.ioutil[*],/usr/bin/perl -MZabbix::Check::Disk -e_ioutil -- $1
+	# Supervisor
+	UserParameter=cpan.zabbix.check.supervisor.installed,/usr/bin/perl -MZabbix::Check::Supervisor -e_installed
+	UserParameter=cpan.zabbix.check.supervisor.running,/usr/bin/perl -MZabbix::Check::Supervisor -e_running
+	UserParameter=cpan.zabbix.check.supervisor.worker_discovery,/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_discovery
+	UserParameter=cpan.zabbix.check.supervisor.worker_status[*],/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_status -- $1
+	# RabbitMQ
+	UserParameter=cpan.zabbix.check.rabbitmq.installed,/usr/bin/perl -MZabbix::Check::RabbitMQ -e_installed
+	UserParameter=cpan.zabbix.check.rabbitmq.running,/usr/bin/perl -MZabbix::Check::RabbitMQ -e_running
+	UserParameter=cpan.zabbix.check.rabbitmq.vhost_discovery[*],/usr/bin/perl -MZabbix::Check::RabbitMQ -e_vhost_discovery -- $1
+	UserParameter=cpan.zabbix.check.rabbitmq.queue_discovery[*],/usr/bin/perl -MZabbix::Check::RabbitMQ -e_queue_discovery -- $1
+	UserParameter=cpan.zabbix.check.rabbitmq.queue_status[*],/usr/bin/perl -MZabbix::Check::RabbitMQ -e_queue_status -- $1 $2 $3
+	# Systemd
+	UserParameter=cpan.zabbix.check.systemd.installed,/usr/bin/perl -MZabbix::Check::Systemd -e_installed
+	UserParameter=cpan.zabbix.check.systemd.system_status,/usr/bin/perl -MZabbix::Check::Systemd -e_system_status
+	UserParameter=cpan.zabbix.check.systemd.service_discovery[*],/usr/bin/perl -MZabbix::Check::Systemd -e_service_discovery -- $1
+	UserParameter=cpan.zabbix.check.systemd.service_status[*],/usr/bin/perl -MZabbix::Check::Systemd -e_service_status -- $1
+	# Time
+	UserParameter=cpan.zabbix.check.time.epoch,/usr/bin/perl -MZabbix::Check::Time -e_epoch
+	UserParameter=cpan.zabbix.check.time.zone,/usr/bin/perl -MZabbix::Check::Time -e_zone
+	UserParameter=cpan.zabbix.check.time.ntp_offset[*],/usr/bin/perl -MZabbix::Check::Time -e_ntp_offset -- $1 $2
+	# Redis
+	UserParameter=cpan.zabbix.check.redis.installed,/usr/bin/perl -MZabbix::Check::Redis -e_installed
+	UserParameter=cpan.zabbix.check.redis.discovery,/usr/bin/perl -MZabbix::Check::Redis -e_discovery
+	UserParameter=cpan.zabbix.check.redis.running[*],/usr/bin/perl -MZabbix::Check::Redis -e_running -- $1
+	UserParameter=cpan.zabbix.check.redis.info[*],/usr/bin/perl -MZabbix::Check::Redis -e_info -- $1 $2
 
-=head3 discovery
+=head1 DISK
+
+Zabbix check for disk
+
+=head2 discovery
 
 discovers disks
 
-=head3 bps $1 $2
+=head2 bps $1 $2
 
 gets disk I/O traffic in bytes per second
 
@@ -38,7 +60,7 @@ $1: I<device name, eg: sda, sdb1, dm-3, ...>
 
 $2: I<type: read|write|total>
 
-=head3 iops $1 $2
+=head2 iops $1 $2
 
 gets disk I/O transaction speed in transactions per second
 
@@ -46,70 +68,59 @@ $1: I<device name, eg: sda, sdb1, dm-3, ...>
 
 $2: I<type: read|write|total>
 
-=head3 ioutil $1 $2
+=head2 ioutil $1
 
 gets disk I/O utilization in percentage
 
 $1: I<device name, eg: sda, sdb1, dm-3, ...>
 
-=head2 Supervisor
+=head1 SUPERVISOR
 
 Zabbix check for Supervisor service
 
-	UserParameter=cpan.zabbix.check.supervisor.installed,/usr/bin/perl -MZabbix::Check::Supervisor -e_installed
-	UserParameter=cpan.zabbix.check.supervisor.running,/usr/bin/perl -MZabbix::Check::Supervisor -e_running
-	UserParameter=cpan.zabbix.check.supervisor.worker_discovery,/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_discovery
-	UserParameter=cpan.zabbix.check.supervisor.worker_status[*],/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_status -- $1
-
-=head3 installed
+=head2 installed
 
 checks Supervisor is installed: 0 | 1
 
-=head3 running
+=head2 running
 
 checks Supervisor is installed and running: 0 | 1 | 2 = not installed
 
-=head3 worker_discovery
+=head2 worker_discovery
 
 discovers Supervisor workers
 
-=head3 worker_status $1
+=head2 worker_status $1
 
 gets Supervisor worker status: RUNNING | STOPPED | ...
 
 $1: I<worker name>
 
-=head2 RabbitMQ
+=head1 RABBITMQ
 
 Zabbix check for RabbitMQ service
 
-	UserParameter=cpan.zabbix.check.rabbitmq.installed,/usr/bin/perl -MZabbix::Check::RabbitMQ -e_installed
-	UserParameter=cpan.zabbix.check.rabbitmq.running,/usr/bin/perl -MZabbix::Check::RabbitMQ -e_running
-	UserParameter=cpan.zabbix.check.rabbitmq.vhost_discovery[*],/usr/bin/perl -MZabbix::Check::RabbitMQ -e_vhost_discovery -- $1
-	UserParameter=cpan.zabbix.check.rabbitmq.queue_discovery[*],/usr/bin/perl -MZabbix::Check::RabbitMQ -e_queue_discovery -- $1
-	UserParameter=cpan.zabbix.check.rabbitmq.queue_status[*],/usr/bin/perl -MZabbix::Check::RabbitMQ -e_queue_status -- $1 $2 $3
-
-=head3 installed
+=head2 installed
 
 checks RabbitMQ is installed: 0 | 1
 
-=head3 running
+=head2 running
 
 checks RabbitMQ is installed and running: 0 | 1 | 2 = not installed
 
-=head3 vhost_discovery $1
+=head2 vhost_discovery $1
 
 discovers RabbitMQ vhosts
 
 $1: I<cache expiry in seconds, by default 0>
 
-=head3 queue_discovery $1
+=head2 queue_discovery $1
 
 discovers RabbitMQ queues
 
 $1: I<cache expiry in seconds, by default 0>
 
-=head3 queue_status $1 $2 $3
+=head2 queue_status $1 $2 $3
 
 gets RabbitMQ queue status using queue discovery cache
 
@@ -119,52 +130,43 @@ $2: I<queue name>
 
 $3: I<type: ready|unacked|total>
 
-=head2 Systemd
+=head1 SYSTEMD
 
 Zabbix check for Systemd services
 
-	UserParameter=cpan.zabbix.check.systemd.installed,/usr/bin/perl -MZabbix::Check::Systemd -e_installed
-	UserParameter=cpan.zabbix.check.systemd.system_status,/usr/bin/perl -MZabbix::Check::Systemd -e_system_status
-	UserParameter=cpan.zabbix.check.systemd.service_discovery[*],/usr/bin/perl -MZabbix::Check::Systemd -e_service_discovery -- $1
-	UserParameter=cpan.zabbix.check.systemd.service_status[*],/usr/bin/perl -MZabbix::Check::Systemd -e_service_status -- $1
-
-=head3 installed
+=head2 installed
 
 checks Systemd is installed: 0 | 1
 
-=head3 system_status
+=head2 system_status
 
 gets Systemd system status: initializing | starting | running | degraded | maintenance | stopping | offline | unknown
 
-=head3 service_discovery
+=head2 service_discovery
 
 discovers Systemd enabled services
 
 $1: I<regex of service name, by default undefined>
 
-=head3 service_status $1
+=head2 service_status $1
 
 gets Systemd enabled service status: active | inactive | failed | unknown | ...
 
 $1: I<service name>
 
-=head2 Time
+=head1 TIME
 
 Zabbix check for system time
 
-	UserParameter=cpan.zabbix.check.time.epoch,/usr/bin/perl -MZabbix::Check::Time -e_epoch
-	UserParameter=cpan.zabbix.check.time.zone,/usr/bin/perl -MZabbix::Check::Time -e_zone
-	UserParameter=cpan.zabbix.check.time.ntp_offset[*],/usr/bin/perl -MZabbix::Check::Time -e_ntp_offset -- $1 $2
-
-=head3 epoch
+=head2 epoch
 
 gets system time epoch in seconds
 
-=head3 zone
+=head2 zone
 
 gets system time zone, eg: +0200
 
-=head3 ntp_offset $1 $2
+=head2 ntp_offset $1 $2
 
 gets system time difference by NTP server
 
@@ -172,18 +174,36 @@ $1: I<server, by defaut pool.ntp.org>
 
 $2: I<port, by default 123>
 
+=head1 REDIS
+
+Zabbix check for Redis service
+
+=head2 installed
+
+checks Redis is installed: 0 | 1
+
+=head2 discovery
+
+discovers Redis instances
+
+=head2 running $1
+
+checks Redis is installed and instance is running: 0 | 1 | 2 = not installed
+
+$1: I<bind, by defaut 127.0.0.1:6379>
+
+=head2 info $1 $2
+
+gets info
+
+$1: I<key>
+
+$2: I<bind, by defaut 127.0.0.1:6379>
+
 =cut
 use strict;
 use warnings;
-no warnings qw(qw utf8);
-use v5.14;
-use utf8;
-use Config;
-use Switch;
-use FindBin;
-use Cwd;
-use File::Basename;
-use File::Slurp;
+use v5.10.1;
 use JSON;
 use Net::NTP;
 use Lazy::Utils;
@@ -192,29 +212,25 @@ use Lazy::Utils;
 BEGIN
 {
 	require Exporter;
-	# set the version for version checking
-	our $VERSION     = '1.10';
-	# Inherit from Exporter to export functions and variables
+	our $VERSION     = '1.11';
 	our @ISA         = qw(Exporter);
-	# Functions and variables which are exported by default
-	our @EXPORT      = qw(zbxEncode zbxDecode printDiscovery _version);
-	# Functions and variables which can be optionally exported
+	our @EXPORT      = qw(zbx_encode zbx_decode print_discovery _version);
 	our @EXPORT_OK   = qw();
 }
 
 
-our @zbxSpecials = qw(\ ' " ` * ? [ ] { } ~ $ ! & ; ( ) < > | # @);
+our @zbx_specials = split(" ", q%\ ' " ` * ? [ ] { } ~ $ ! & ; ( ) < > | \# @%);
 
 
-sub zbxEncode
+sub zbx_encode
 {
 	my $result = "";
 	my ($str) = @_;
-	return $result unless $str;
+	return $result unless defined($str);
 	for (my $i = 0; $i < length $str; $i++)
 	{
 		my $chr = substr $str, $i, 1;
-		if (not $chr =~ /[ -~]/g or grep ($_ eq $chr, (@zbxSpecials, '%', ',')))
+		if (not $chr =~ /[ -~]/g or grep($_ eq $chr, (@zbx_specials, '%', ',')))
 		{
 			$result .= uc sprintf("%%%x", ord($chr));
 		} else
@@ -225,11 +241,11 @@ sub zbxEncode
 	return $result;
 }
 
-sub zbxDecode
+sub zbx_decode
 {
 	my $result = "";
 	my ($str) = @_;
-	return $result unless $str;
+	return $result unless defined($str);
 	my ($i, $len) = (0, length $str);
 	while ($i < $len)
 	{
@@ -248,19 +264,19 @@ sub zbxDecode
 	return $result;
 }
 
-sub printDiscovery
+sub print_discovery
 {
 	my @items = @_;
 	my $discovery = {
 		data => [
 			map({
-				my $item = $_; 
+				my $item = $_;
 				my %newitem = map({
 					my $key = $_;
 					my $val = $item->{$key};
-					my $newkey = zbxEncode($key);
+					my $newkey = zbx_encode($key);
 					$newkey = uc("{#$newkey}");
-					my $newval = zbxEncode($val);
+					my $newval = zbx_encode($val);
 					$newkey => $newval;
 				} keys(%$item));
 				\%newitem;
@@ -281,9 +297,6 @@ sub _version
 }
 
 
-my $osname = $Config{osname};
-warn "OS '$osname' is not supported" unless $osname eq 'linux';
-
 1;
 __END__
 =head1 INSTALLATION
@@ -307,26 +320,6 @@ This module requires these other modules and libraries:
 
 =item *
 
-Switch
-
-=item *
-
-FindBin
-
-=item *
-
-Cwd
-
-=item *
-
-File::Basename
-
-=item *
-
-File::Slurp
-
-=item *
-
 JSON
 
 =item *
@@ -347,11 +340,11 @@ B<CPAN> L<https://metacpan.org/release/Zabbix-Check>
 
 =head1 AUTHOR
 
-Orkun Karaduman <orkunkaraduman@gmail.com>
+Orkun Karaduman (ORKUN) <orkun@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016  Orkun Karaduman <orkunkaraduman@gmail.com>
+Copyright (C) 2017  Orkun Karaduman <orkunkaraduman@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
