@@ -5,41 +5,16 @@ Zabbix::Check::Supervisor - Zabbix check for Supervisor service
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
 Zabbix check for Supervisor service
 
-	UserParameter=cpan.zabbix.check.supervisor.installed,/usr/bin/perl -MZabbix::Check::Supervisor -e_installed
-	UserParameter=cpan.zabbix.check.supervisor.running,/usr/bin/perl -MZabbix::Check::Supervisor -e_running
-	UserParameter=cpan.zabbix.check.supervisor.worker_discovery,/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_discovery
-	UserParameter=cpan.zabbix.check.supervisor.worker_status[*],/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_status -- $1
-
-=head3 installed
-
-checks Supervisor is installed: 0 | 1
-
-=head3 running
-
-checks Supervisor is installed and running: 0 | 1 | 2 = not installed
-
-=head3 worker_discovery
-
-discovers Supervisor workers
-
-=head3 worker_status $1
-
-gets Supervisor worker status: RUNNING | STOPPED | ...
-
-$1: I<worker name>
-
 =cut
 use strict;
 use warnings;
-no warnings qw(qw utf8);
-use v5.14;
-use utf8;
+use v5.10.1;
 use Lazy::Utils;
 
 use Zabbix::Check;
@@ -48,25 +23,22 @@ use Zabbix::Check;
 BEGIN
 {
 	require Exporter;
-	# set the version for version checking
-	our $VERSION     = '1.10';
-	# Inherit from Exporter to export functions and variables
+	our $VERSION     = '1.11';
 	our @ISA         = qw(Exporter);
-	# Functions and variables which are exported by default
 	our @EXPORT      = qw(_installed _running _worker_discovery _worker_status);
-	# Functions and variables which can be optionally exported
 	our @EXPORT_OK   = qw();
 }
 
 
-our ($supervisorctl) = whereisBin('supervisorctl');
-our ($supervisord) = whereisBin('supervisord');
+our ($supervisorctl) = whereis('supervisorctl');
+our ($supervisord) = whereis('supervisord');
+our ($python) = whereis('python');
 
 
-sub getStatuses
+sub get_statuses
 {
 	return unless $supervisorctl;
-	my $result = fileCache("all", 30, sub
+	my $result = file_cache("all", 30, sub
 	{
 		my $result = {};
 		for (`$supervisorctl status 2>/dev/null`)
@@ -92,7 +64,7 @@ sub _running
 	my $result = 2;
 	if ($supervisorctl)
 	{
-		system "pgrep -f '/usr/bin/python $supervisord' >/dev/null 2>&1";
+		system "pgrep -f '$python $supervisord' >/dev/null 2>&1";
 		$result = ($? == 0)? 1: 0;
 	}
 	print $result;
@@ -102,20 +74,20 @@ sub _running
 sub _worker_discovery
 {
 	my @items;
-	my $statuses = getStatuses();
+	my $statuses = get_statuses();
 	@items = map({ name => $_}, keys %$statuses) if $statuses;
-	return printDiscovery(@items);
+	return print_discovery(@items);
 }
 
 sub _worker_status
 {
-	my ($name) = map(zbxDecode($_), @ARGV);
-	return unless $name;
+	my ($name) = map(zbx_decode($_), @ARGV);
+	return "" unless $name;
 	my $result = "";
-	my $statuses = getStatuses();
-	$result = $statuses->{$name} if $statuses->{$name};
+	my $statuses = get_statuses();
+	$result = $statuses->{$name} if defined($statuses->{$name});
 	print $result;
-	return $result;	
+	return $result;
 }
 
 
@@ -129,11 +101,11 @@ B<CPAN> L<https://metacpan.org/release/Zabbix-Check>
 
 =head1 AUTHOR
 
-Orkun Karaduman <orkunkaraduman@gmail.com>
+Orkun Karaduman (ORKUN) <orkun@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016  Orkun Karaduman <orkunkaraduman@gmail.com>
+Copyright (C) 2017  Orkun Karaduman <orkunkaraduman@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
